@@ -1,6 +1,6 @@
 from argparse import ArgumentParser, Namespace
 from json import load
-from pprint import pprint as print
+from pprint import pprint
 from typing import Any
 
 
@@ -11,10 +11,11 @@ def getKwargs() -> Namespace:
     )
 
     parser.add_argument(
-        "-j",
-        "--json",
+        "-i",
+        "--input",
         type=str,
-        help="JSON file to pretty print",
+        help="Input file to pretty print",
+        required=False
     )
 
     return parser.parse_args()
@@ -22,20 +23,24 @@ def getKwargs() -> Namespace:
 
 def loadJSON(filename: str) -> Any:
     data: Any
-    with open(file=filename, mode="r") as file:
-        data = load(file)
-        file.close()
-    return data
+    try:
+        with open(file=filename, mode="r") as file:
+            data = load(file)
+            file.close()
+        return data
+    except FileNotFoundError:
+        print("Invalid file path")
+        quit(2)
 
 
 def main() -> None:
     args: Namespace = getKwargs()
 
-    if args.json[-5::] != ".json":
-        print("Invalid JSON file extension")
-        quit(1)
+    if args.input[-5::] == ".json":
+        pprint(loadJSON(args.input))
     else:
-        print(loadJSON(args.json))
+        print("Invalid file extension")
+        quit(1)
 
 
 if __name__ == "__main__":
